@@ -6,11 +6,12 @@ from cytra.auth import Authenticator
 
 
 class AuthAppMixin:
-    __authenticator__ = Authenticator
+    authenticator = Authenticator
     auth = None
-    identity = None
 
     def on_begin_request(self):
+        self.identity = None
+
         if self.auth:
             self.auth.authenticate_request()
 
@@ -20,10 +21,18 @@ class AuthAppMixin:
         super().on_end_response()
         self.identity = None
 
+    @property
+    def identity(self):
+        return self.request.identity
+
+    @identity.setter
+    def identity(self, value):
+        self.request.identity = value
+
     def setup(self):
         super().setup()
         if "auth" in self.config:
-            self.auth = self.__authenticator__(app=self)
+            self.auth = self.__class__.authenticator(app=self)
             self.cors.allow_headers.add("authorization")
             self.cors.expose_headers.add("x-new-jwt-token")
         else:
@@ -32,7 +41,6 @@ class AuthAppMixin:
     def shutdown(self):
         if self.auth is not None:
             self.auth = None
-            self.identity = None
         super().shutdown()
 
     def authorize(self, *roles):
