@@ -9,7 +9,7 @@ from cytra.auth.principal import JWTPrincipal, DefaultJWTPrincipal
 
 class Authenticator:
     header_token_key = "HTTP_AUTHORIZATION"
-    __jwt_principal__ = DefaultJWTPrincipal
+    jwt_principal = DefaultJWTPrincipal
 
     def __init__(self, app) -> None:
         self.app = app
@@ -19,7 +19,7 @@ class Authenticator:
 
     def get_principal(self) -> Union[None, JWTPrincipal]:
         try:
-            return self.__class__.__jwt_principal__(app=self.app).load(
+            return self.__class__.jwt_principal(app=self.app).load(
                 self.app.request.environ[self.header_token_key]
             )
 
