@@ -28,6 +28,9 @@ class DotDict(dict):
     def __getitem__(self, key):
         return dot_object(super().__getitem__(key))
 
+    def get(self, key, default=None):
+        return dot_object(super().get(key, default))
+
     def __getattr__(self, key):
         return self.__getitem__(key)
 
